#
# spec file for package telepathy-glib
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           telepathy-glib
Version:        0.24.2
Release:        1.13
Summary:        GObject-based library for the Telepathy D-Bus API
License:        LGPL-2.1-or-later
Group:          Development/Languages/C and C++
URL:            http://telepathy.freedesktop.org/
Source:         http://telepathy.freedesktop.org/releases/telepathy-glib/%{name}-%{version}.tar.gz
Source99:       baselibs.conf

BuildRequires:  gtk-doc >= 1.17
BuildRequires:  libxslt-devel
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.16.0
BuildRequires:  pkgconfig(dbus-1) >= 0.95
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.90
BuildRequires:  pkgconfig(gio-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30

%description
The telepathy-glib library is a GObject-based C binding for the
Telepathy D-Bus API.

%package -n libtelepathy-glib0
Summary:        GObject-based library for the Telepathy D-Bus API
Group:          Development/Languages/C and C++

%description -n libtelepathy-glib0
The telepathy-glib library is a GObject-based C binding for the
Telepathy D-Bus API.

%package -n typelib-1_0-TelepathyGlib-0_12
Summary:        GObject-based library for the Telepathy D-Bus API -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-TelepathyGlib-0_12
The telepathy-glib library is a GObject-based C binding for the
Telepathy D-Bus API.

This package provides the GObject Introspection bindings for the
telepathy-glib library.

%package devel
Summary:        GObject-based library for the Telepathy D-Bus API -- Development Files
Group:          Development/Languages/C and C++
Requires:       glibc-devel
Requires:       libtelepathy-glib0 = %{version}
Requires:       typelib-1_0-TelepathyGlib-0_12 = %{version}

%description devel
The telepathy-glib library is a GObject-based C binding for the
Telepathy D-Bus API.

%package doc
Summary:        GObject-based library for the Telepathy D-Bus API -- Developer documentation
Group:          Development/Languages/C and C++
Requires:       libtelepathy-glib0 = %{version}

%description doc
The telepathy-glib library is a GObject-based C binding for the
Telepathy D-Bus API.

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--enable-vala-bindings \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libtelepathy-glib0 -p /sbin/ldconfig
%postun -n libtelepathy-glib0  -p /sbin/ldconfig

%files -n libtelepathy-glib0
%license COPYING
%{_libdir}/libtelepathy-glib*.so.0*

%files -n typelib-1_0-TelepathyGlib-0_12
%{_libdir}/girepository-1.0/TelepathyGLib-0.12.typelib

%files devel
%dir %{_includedir}/telepathy-1.0
%{_includedir}/telepathy-1.0/telepathy-glib/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/telepathy-glib.*

%files doc
%{_datadir}/gtk-doc/html/telepathy-glib

%changelog
* Tue Feb  9 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.24.2:
  + Enhancements:
  - Port build tools to Python 3
  - Update and fix tests for Python 3
  + Fixes:
  - Stop hardcoding python's path in .py scripts
  - Fixed some code issues discovered by compiling with clang
  - Replaced tp_verify_* with G_STATIC_ASSERTs, fixing the build
    with more recent gtk-doc
  - autogen.sh: run gtkdocize from $srcdir in out-of-source
    builds
  - Tests:
    . Fix build failure with glib >= 2.46 due to duplicate test
    paths
    . Fix a service file path to fix the build with installed
    tests
  - call-channel: fix a memory leak
  - debug-sender: fix messages queue locking
  - TpBasePasswordChannel: fix gtk-doc comment for finished
    signal
  - protocol: fix a memory leak
  - Fix a crash when creating a conference call
* Fri Dec  4 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Drop python-xml BuildRequires: the installation is using python3.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Thu Apr 14 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Remove upstreamed patches: 0001-fix-file-path-leaks.patch
  0001-tp_list_connection_managers_async-terminate-properly.patch
* Mon Aug 25 2014 zaitor@opensuse.org
- Update to version 0.24.1:
  + Fixes:
  - base-client: fix potential uninitialized variable bug.
  - Fix a potential crash in contact-list example (fdo#79006).
* Sun Apr  6 2014 dimstar@opensuse.org
- Update to version 0.24.0:
  + Don't leak every D-Bus method call result, a regression in
    0.23.1.
- Changes from version 0.23.3:
  + Enhancements:
  - TpProtocol gained API to access to its immutable properties
    as a GVariant (fdo#55108).
  - TpCallStream and TpCallContent now inherit the factory from
    their TpCallChannel (fdo#76168).
  + Fixes:
  - Fix a memory leak when cleaning up TpProxy "prepare" requests
    (fdo#76000).
  - Fix a memory leak for paths to contacts' avatar data
    (fdo#76000).
  - Fix crashes in TpFileTransferChannel with GLib 2.39
    (fdo#72319).
  - Fix some paths memory leaks (fdo#76119).
  - tp_list_connection_managers_async() now terminates properly
    if there is no CM installed (fdo#68892).
* Fri Mar 28 2014 mgorse@suse.com
- Add 0001-fix-file-path-leaks.patch: fix leak when calling
  g_file_get_path (fdo#76119).
* Fri Mar 21 2014 fcrozat@suse.com
- Add
  0001-tp_list_connection_managers_async-terminate-properly.patch:
  terminate properly if there is no CM [fdo#68892]
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 0.23.2:
  + Enhancements:
  - TpBaseConnection now has an "account-path-suffix" property
    (fdo#74030).
  - New high level TpAccountChannelRequest API, including tubes,
    Conference and SMSChannel (fdo#75450).
  - 'TargetHandleType: None' is now automatically added when
    requesting a channel with TpAccountChannelRequest if no
    handle type has been defined (fdo#75450).
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 0.23.1:
  + Dependencies: GLib 2.36 or later is required.
  + Deprecations: TpPresenceMixin: optional arguments are
    deprecated, apart from a string named "message". This matches
    our current D-Bus API.
  + Enhancements:
  - tp_protocol_normalize_contact_async(),
    tp_protocol_identify_account_async(), and high-level API for
    the Protocol Addressing and Presence interfaces (fdo#71048).
  - More accessors for TpPresenceStatusSpec, which is now a boxed
    type (fdo#71048).
  - tp_connection_manager_param_dup_variant_type() (fdo#71093).
  - Better debug output (fdo#68390, fdo#71048).
  + Fixes:
  - In the examples, specifically ask for "TelepathyGlib-0.12"
    (this API version), not Telepathy 1.0 (fdo#49737).
  - Improve tests' isolation from the real session bus.
  - Fix a critical warning for each new connection under GLib
    2.39 (fdo#72303).
  - Fix some possible crashes in file transfer channels,
    particularly under GLib 2.39 (fdo#72319).
  - Correct tp_account_request_set_avatar documentation.
  - Fix a TpConnection reference-leak in TpBaseClient.
- Changes from version 0.23.0:
  + Dependencies: GLib 2.34 or later is required.
  + Enhancements:
  - Spec 0.27.3:
    . Added Conn.I.Sidecars1.
    . Added Conn.I.Renaming.
    . Added CD.I.Messages1.
  - TpAccount::avatar-changed signal (fdo#52938).
  - tp_value_array_free: equivalent of g_value_array_free but
    does not provoke deprecation warnings from GLib (fdo#69849).
  - tp_account_is_prepared and tp_account_manager_is_prepared are
    now deprecated.
  + Fixes:
  - tp_contact_set_attributes: don't warn on genuinely absent
    interfaces (fdo#68149).
  - channel-group: don't crash if no message has been provided.
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 0.22.1:
  + In the examples, specifically ask for "TelepathyGlib-0.12"
    (this API version), not Telepathy 1.0 (fdo#49737).
  + Fix a critical warning for each new connection under GLib 2.39
    (fdo#72303).
  + Fix a TpConnection reference-leak in TpBaseClient.
  + channel-group: don't crash if no message has been provided.
* Wed Oct  2 2013 dimstar@opensuse.org
- Update to version 0.22.0:
  + When an avatar is downloaded, announce the change to the avatar
    token immediately; if the avatar changes from A to B while
    we're still doing the asynchronous file saving, don't set A as
    the new avatar when it has been saved (fdo#70010).
* Sun Sep 29 2013 zaitor@opensuse.org
- Update to version 0.21.2:
  + Enhancements:
  - Writing avatars into cache now uses asynchronous I/O
    (fdo#63402).
  - telepathy-spec 0.27.2: add SelfID, SelfContactChanged.
  - tp_dbus_properties_mixin_dup_all() is now public (fdo#69283).
  - TpBaseProtocol now lists Presence.Statuses as an immutable
    property (fdo#69520).
  - TpBaseConnection: Implement SelfID and SelfContactChanged as
    defined in spec 0.27.2.
  - The inspect-cm example now inspects all CMs if run without
    arguments (fdo#68390).
  + Fixes:
  - Don't crash if GetContactInfo() fails (fdo#46430).
  - Fix a race condition that could result in telepathy-haze
    protocol support not being detected (fdo#67183).
  - Fix documentation for tp_connection_get_self_handle.
  - Make TpHeap work correctly with GComparator functions that
    return values outside {-1, 0, 1} (fdo#68932).
  - Examples have been updated to use more recent API.
  - Better debug-logging (fdo#68390).
* Wed Sep  4 2013 coolo@suse.com
- Add baselibs.conf to satisfy libgoa-backend-1_0-1-32bit.
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 0.21.1:
  + Fixes:
  - Fix a wrong introspection annotation on
    tp_debug_client_get_messages_finish() that would lead to
    use-after-free (fdo#65518).
  - Isolate regression tests better (fdo#63119).
  - Explicitly annotate tp_account_update_parameters_finish()'s
    'unset_parameters' argument to be a NULL-terminated string
    array. It was previously incorrectly inferred to be a string,
    for some reason.
  - Always flag delivery reports with Non_Text_Content.
    (fdo#61254).
  - Don't announce legacy Group channels twice (fdo#52011).
  - Don't crash if a broken connection manager signals a
    TLSCertificate with no CertificateChainData, just invalidate
    the channel (fdo#61616).
  - Adjust regression tests so we can distcheck under Automake
    1.13, and various other build-system updates (fdo#65517).
* Wed Apr  3 2013 dimstar@opensuse.org
- Update to version 0.21.0:
  + Enhancements:
  - Code-generation now copes with ${PYTHON} being set to
    Python 3; Python 2 remains fully supported (fdo#56758).
  - Add uri-schemes property on TpAccount, with
    notify::uri-schemes emitted if using a recent AcountManager
    like Mission Control 5.15 or later.
  + Fixes:
  - Remove the pkg-config dependency from .pc files.
  - In TpSimpleClientFactory, don't crash when ensuring a contact
    for an obsolete connection manager without "immortal handles"
    fails.
  - Add missing (element-type) introspection annotations to
    tp_capabilities_get_channel_classes, tp_asv_get_bytes and
    tp_client_channel_factory_dup_channel_features (fdo#58851).
  - Don't emit the NewChannels signal twice for the obsolete
    ContactList GROUP channels (fdo#52011).
  - Fix builds with Automake 1.13 (fdo#59604).
  - Fix unit tests when running with glib >=2.36 (fdo#63069).
  - Fix refcycle preventing TpConnection objects to be freed.
    (fdo#63027).
- Drop upstream fixed patches:
  + tg-tests-simple-account-add-uri.patch.
  + tg-add-TpAccount-uri-schemes-property.patch.
  + tg-implement-change-notification-on-uri-schemes-property.patch.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Sun Jan 13 2013 zaitor@opensuse.org
- Add tg-add-TpAccount-uri-schemes-property.patch,
  tg-implement-change-notification-on-uri-schemes-property.patch
  and tg-tests-simple-account-add-uri.patch, needed to ensure
  visual feedback on sip accounts changes (fdo#40393).
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 0.20.1:
  + In Call channels, ignore state transitions where the state did
    not actually change (fdo#56044).
  + Process the SelfHandleChanged signal for non-obsolete
    connection managers (fdo#55666).
* Thu Oct  4 2012 dimstar@opensuse.org
- Update to version 0.20.0:
  + There were no code changes since 0.19.10.
* Wed Sep 26 2012 zaitor@opensuse.org
- Update to version 0.19.10:
  + Enhancements:
  - Add tp_vardict_get_uint32() etc., analogous to
    tp_asv_get_uint32() etc.
  - tp_channel_dispatch_operation_get_channels() is now
    introspected (fdo#55102).
  - Add tp_vardict_get_*() helper functions to lookup values in a
    GVariant of type %%G_VARIANT_TYPE_VARDICT.
  - Add tp_variant_convert() and tp_variant_type_classify() to
    manipulate and convert GVariant.
  - A bunch of GVariant oriented API have been added as an
    alternative of their GValue equivalent: fdo#55024,
    fdo#55096, fdo#55099, fdo#55101, fdo#55024, fdo#55095 and
    fdo#55100.
* Wed Sep 12 2012 vuntz@opensuse.org
- Update to version 0.19.9:
  + Enhancements:
  - Some functions from util.h, such as tp_utf8_make_valid(),
    tp_escape_as_identifier() and user-action-time functions are
    now available via gobject-introspection (fdo#54543)
  + Fixes:
  - Get the remote contact from a MediaDescription correctly
    (fdo#54425)
  - Fix an incorrect error on UpdateLocalMediaDescription
  - Fix use of an unterminated string in the tls-certificates
    test
  - Fix service-side codegen using single includes, which
    prevents extensions to build with TP_DISABLE_SINGLE_INCLUDE.
  + Several API deprecations.
- Changes from version 0.19.8:
  + Enhancements:
  - New introspectable function
    tp_account_channel_request_set_hint() to add hints one by
    one.
  + Fixes:
  - Set the ChannelRequests immutable properties when
    observing/handling channels.
- Changes from version 0.19.7:
  + Enhancements:
  - Add API to TpBaseChannel to allow it to disappear and
    reappear from the bus without disposing the object
    (fdo#48210)
  + Fixes:
  - In tp_account_dup_storage_identifier_variant, don't fail if
    there is no storage identifier (fdo#53201)
  - Remove duplicate TpBaseConnection typedef, fixing compilation
    with pre-C11 compilers like gcc < 4.6 (fdo#53100)
  - Use AS_CASE instead of case/esac, and AS_IF instead of
    if/then/[else/]fi in configure.ac, as they are safer and
    guaranteed to work (fdo#681413)
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 0.19.6:
  + Enhancements:
  - Add tp_account_manager_can_set_default()
  + Fixes:
  - Fix generation of reentrant-methods.list in highly parallel
    builds (fdo#52480)
  - TpBaseChannel: assert that the subclass sets
    TargetHandleType.
* Fri Aug  3 2012 dimstar@opensuse.org
- Update to version 0.19.5:
  + fdo#52441: fix warning when preparing blocked contacts before
    TP_CONNECTION_FEATURE_CONNECTED is officially prepared.
  + TpAccountManager: set the requested presence on newly created
    accounts
- Changes from version 0.19.4:
  + Enhancements:
  - TpBaseConnectionManager, TpBaseConnection and TpBaseProtocol:
    add virtual methods to get interfaces.
  - Add tp_account_request_set_storage_provider().
  + Fixes:
  - base-connection: return from RequestHandles if called with no
    names.
  - TpAccountRequest: add missing 'service' property getter.
- Changes from version 0.19.3:
  + Fix Crash in TpBaseClient (fdo#51444)
  + Several API deprecations.
- Changes from version 0.19.2:
  + Enhancements:
  - TpDynamicHandleRepo can now have an asynchronous ID
    normalization function.
  + Fixes:
  - tp_debug_client_get_messages_async: error is not propagated
    (fdo#51250)
* Thu Aug  2 2012 dimstar@opensuse.org
- Update to version 0.19.1:
  + Enhancements:
  - New TpAccountRequest object to help account creation
  - TpSimpleClientFactory gained API to prepare TpContact objects
    with the features set on it.
  - tp_simple/automatic_client_factory_new() now accept NULL
    TpDBusDaemon arg.
  + Fixes:
  - Fixed possible case where TP_CONTACT_FEATURE_AVATAR_DATA does
    not get prepared.
  - Fix Vala bindings build when srcdir is different from
    builddir. (fdo#49802)
  + Several API deprecations.
- Changes from version 0.19.0:
  + Enhancements:
  - <telepathy-glib/telepathy-glib.h> now includes all
    non-generated code except proxy-subclass.h. Please use it
    instead of individual headers
  - A new meta-header, <telepathy-glib/telepathy-glib-dbus.h>,
    now includes all generated code.
  - Replace --disable-coding-style-checks and
  - -disable-doc-checks with --disable-fatal-warnings.
  - Add TpRoomList and TpRoomInfo (fdo#30338)
  - Add TpDebugClient (fdo#23344)
  - Add tp_account_channel_request_new_text(),
    tp_account_channel_request_new_audio_call(),
    tp_account_channel_request_set_target_contact() etc., which
    do not require the caller to know D-Bus property names
    (fdo#48780)
  - Add tp_connection_dup_detailed_error_vardict(),
    tp_base_connection_disconnect_with_dbus_error_vardict(),
    tp_connection_manager_param_dup_default_variant(),
    tp_capabilities_dup_channel_classes_variant() which
    use/return GVariants instead of dbus-glib parameterized types
  - Add a simple PyGtk3 dialler to the examples, and optionally
    install the Python examples as well as the C ones (fdo#48504)
  - Add tp_contact_get_account()
  - Improve documentation
  - Add "clean-for-new-branch" Makefile target which is more
    thorough than clean, but less thorough than distclean
  - Add TpTLSCertificate, a TpProxy subclass representing a TLS
    certificate (fdo#30460)
  - TpMessageMixin now has helpers to implement the ChatState
    interface.
  + Fixes:
  - Make it safe to hold refs to a remaining GAsyncResult after
    returning to the main loop (fdo#45554)
  - When a TpProxy method call returns, which can occasionally be
    synchronous, use an idle to finish the corresponding
    GAsyncResult (fdo#45514)
  - Add TP_NUM_DBUS_ERRORS (etc.) to supersede NUM_TP_DBUS_ERRORS
    (fdo#46470)
  - Make several methods returning a GStrv introspectable
    (fdo#46471)
  - Retry preparation of features that depended on a missing
    connection interface after the connection connects, in the
    hope that the interface has now become available (fdo#42981)
  - Interpret capabilities more strictly, avoiding falsely saying
    we support channel requests with fixed properties we don't
    understand.
  + Several API deprecations.
* Wed Aug  1 2012 dimstar@opensuse.org
- Update to version 0.18.2:
  + Enhancements:
  - Add "clean-for-new-branch" Makefile target which is more
    thorough than clean, but less thorough than distclean
  + Fixes:
  - Retry preparation of features that depended on a missing
    connection interface after the connection connects
    (fdo#42981)
  - Fix warning when preparing blocked contacts before
    TP_CONNECTION_FEATURE_CONNECTED is officially prepared
    (fdo#52441)
  - Fix Vala bindings build when srcdir is different from
    builddir (fdo#49802).
* Mon Apr 23 2012 vuntz@opensuse.org
- Update to version 0.18.1:
  + Enhancements:
  - Make various methods of the form get_foo() available to
    gobject-introspection
  - Improve stream tube examples
  - Improve documentation
  + Fixes:
  - Change the type of TpStreamTubeConnection::closed's argument
    from POINTER to ERROR so PyGI can bind it
  - Avoid TpCallChannel potentially returning a TpContact with no
    identifier
  - Use the right macro to avoid post-2.30 GLib APIs
  - Fix warnings with newer gtk-doc and g-ir-scanner (fdo#48592,
    fdo#48363, fdo#48620)
  - Make various warnings non-fatal for this stable branch: GIR
    scanner warnings, documentation completeness, and deprecated
    functions (fdo#48363)
  - Don't hard-code use of a particular abstract socket in
    dbus-tube-chan test, fixing test failure on non-Linux
    (fdo#48600)
* Tue Apr  3 2012 vuntz@opensuse.org
- Update to version 0.18.0:
  + Support the DownloadAtConnection property in TpBaseContactList.
  + Add high-level API for TpDBusTubeChannel classes (fdo#29271).
  + Various improvements to the ContactList test suite.
* Fri Mar 23 2012 praful.johari@gmail.com
- Update to version 0.17.7:
  + Enhancements:
  - Use close_channels_async on the channel dispatch operation in
    the example approver.
  - API additions
  + Fixes:
  - TpBaseMediaCallContent: be sure to update the local sending
    state on call acceptance.
  - A few miscellaneous fixes to the Call1 code.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 0.17.6:
  + Enhancements:
  - TpCapabilities: add API to check for Call and FileTransfer
    support
  - Use GObject's FFI-based generic marshaller instead of
    generating our own marshallers (fdo#46523)
  - Add tp_list_connection_managers_async,
    tp_protocol_dup_params, tp_protocol_dup_param,
    tp_protocol_borrow_params,
    tp_connection_manager_dup_protocols
  - Add accessors for TpAccount properties, parameters and
    storage identifier represented as a GVariant (fdo#30422)
  - TpCallChannel: add API to put the call on hold.
  - TpCallContentMediaDescription now implements the
    RTPHeaderExtensions, RTCPFeedback and RTCPExtendedReports
    interfaces.
  + Fixes:
  - Don't change the direction of Call streams because of a Hold
  - Use the right error when rejecting incompatible codecs
  - Reject local updates to a media description while an offer is
    pending
  - Avoid forward-declaring Call classes, fixing compilation on
    clang, older gcc, and other compilers not targeting C1x
  - Fix namespaces in example_call.manager
  - Produce self-contained header files from
    glib-interfaces-gen.py (fdo#46835)
  - Correctly implement and document tp_call_channel_has_dtmf()
  - Fix various build failures in out-of-tree or parallel builds,
    and don't rebuild everything whenever the documentation
    changes (fdo#36398)
  - Improve test coverage for the connection manager test
    (fdo#46358)
  - TpCallChannel::state-changed is properly annotate (fdo#47410)
  + Several API deprecations, see NEWS for details.
- Add explicit pkgconfig(glib-2.0) BuildRequires so it can be
  versioned.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 0.17.5:
  + Enhancements:
  - telepathy-spec 0.25.2:
    · the Call1 family of interfaces
    · Conn.I.Addressing1
    · Chan.I.CaptchaAuthentication1
    · Account.Supersedes
  - Add TpCallChannel, TpBaseCallChannel and other Call-related
    high-level API.
  - tp_account_manager_get_most_available_presence() now returns
    (AVAILABLE, "available, "") if the only connected accounts
    does not implement SimplePresence.
  - Add tp_base_channel_get_self_handle().
  - TpBaseChannel now has a virtual get_interfaces() method.
  - tp_connection_disconnect_async: high level API to disconnect
    a TpConnection.
  - tp_unix_connection_receive_credentials_with_byte() and
    tp_unix_connection_send_credentials_with_byte() now have
    async equivalents.
  - Produce DLL files when compiled for Windows.
  + Fixes:
  - fdo#45554: fix use-after-free if various async results are
    kept until after the callback has returned, which is
    considered valid.
  - tp_account_manager_get_most_available_presence() now returns
    ("offline, "") as status and message if no account is
    connected, as stated in the doc, instead of (NULL, NULL).
  - TpChannel: fix a crash when preparing contacts.
  - fdo#45982: fix a crash in TpBaseContactList when using
    RenameGroup()'s fallback code.
* Mon Jan  9 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  No indication of LGPL-2.1 only files
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 0.17.4:
  + Fixes:
  - Set the right source on
    tp_account_set_uri_scheme_association_async's GAsyncResult.
  - fdo#43755: Fix a crash when participating in a XMPP MUC
    containing members with an unknown real JID.
- Rewrite summaries and descriptions.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-TelepathyGlib-0_12
  subpackage.
- Add typelib-1_0-TelepathyGlib-0_12 Requires to devel subpackage.
* Tue Nov 29 2011 dimstar@opensuse.org
- Update to version 0.17.3:
  + Fixes:
  - Fix a crash in TpSimplePasswordManager
  + Enhancements:
  - Add high level API to check if a connection supports settings
    aliases on contacts.
* Fri Nov 25 2011 dimstar@opensuse.org
- Update to version 0.17.2:
  + Speculatively replace _free/_destroy with _unref everywhere,
    and add a coding style check.
  + Ensure GSocketConnection objects are properly closed and freed
    for incoming TpFileTransferChannels.
  + Many documentation nits have been fixed.
  + Building the GObject-Introspection repository now works
    reliably when using `make -j`
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 0.17.1:
  + Enhancements:
  - telepathy-glib now generates code for spec version 0.25.0.
  - fdo#39188: add high level API to accept and provide file
    transfers.
- Changes from version 0.17.0:
  + Enhancements:
  - fdo#41801: add high level API to block/unblock contacts.
  - fdo#42546: add TP_CONNECTION_FEATURE_CONTACT_LIST_PROPERTIES
    a feature preparing ContactList's properties without
    preparing the contact list itself.
  - fdo#42503: the TpChannelDispatchOperation passed to
    TpBaseClientClassObserveChannelsImpl is now prepared.
  - fdo#41455: it's now possible to install tp-glib's test suite.
- Changes from version 0.16.2:
  + Fixes:
  - Improve documentation of the TpProxy::invalidated signal.
  - fdo#42305: TpGroupMixin: always set the
    Members_Changed_Detailed flag.
  - fdo#42670: fix a crash when preparing
    TP_CHANNEL_FEATURE_CONTACTS on a channel containing contacts
    without known owners.
* Thu Oct 27 2011 dimstar@opensuse.org
- Update to version 0.16.1:
  + Fixes:
  - fdo#42063: circular introspection dependency between
    connection and contacts.
  - fdo#42049: TpBaseContactList now implements
    TP_TOKEN_CONNECTION_INTERFACE_CONTACT_BLOCKING_BLOCKED.
  - fdo#41928: Don't crash if the owner of some members of a
    TpChannel are unknown.
  - fdo#41929: Don't crash if a TpTextChannel receives a message
    not having a sender.
* Sat Oct 15 2011 vuntz@opensuse.org
- Update to version 0.16.0:
  + Fixes:
  - fdo#41729: TpChannel now trusts the ChannelType property
    included in the dictionary of immutable properties passed to
    its constructor.
  - fdo#41714: TpAccount:normalized-name now refers to XMPP JIDs
    and ICQ UINs, to give examples of what its value means.
* Wed Oct 12 2011 vuntz@opensuse.org
- Update to version 0.15.9:
  + Fixes:
  - fdo#41697: unknown handle owners in chat rooms no longer
    crashes TpChannel.
- Changes from version 0.15.8:
  + Enhancements:
  - telepathy-glib now generates code for spec version 0.24.0,
    including the Room, Subject and RoomConfig interfaces.
  - It is now possible to set D-Bus properties as if in response
    to a call to Set() on the bus, using
    tp_dbus_properties_mixin_set(). Help fix fdo#32416.
  + Fixes:
  - fdo#41470: crash in some situations when using
    TP_CHANNEL_FEATURE_CONTACTS.
* Wed Oct  5 2011 vuntz@opensuse.org
- Update to version 0.15.7:
  + Fixes:
  - fdo#40555: Memory leaks in TpConnection and protocol.c
  - Memory leak if the debug message cache is disabled
  - fdo#38060: Fix a crash in TpMessageMixin, triggered by
    delivery reports.
  - fdo#38997: Cope beter if UNIX sockets are not supported.
  - fdo#40523: Connection Manager crash when a client acks the
    same message twice.
  - fdo#41414: Make sure tp_connection_upgrade_contacts() is
    no-op if all features are already prepared.
  - fdo#41368: Fix introspection.
  - fdo#41435: Ensure sent messages have a sender even with
    butterfly, which does not set "message-sender".
* Sat Oct  1 2011 zaitor@opensuse.org
- Update to version 0.15.6:
  + Enhancements:
  - New JavaScript (gjs) code example to demonstrate
    GObject-Introspection of the API.
  - TpProtocol: new API to get avatars requirements.
  - Factory features are now prepared on various contacts:
    . TpConnection's self contact;
    . TpChannel's target, initiator and self contacts;
    . TpChannel's group members;
    . TpTextChannel's message sender;
    . TpStreamTubeChannel's connection contact.
  - New object TpDBusTubeChannel to represent a D-Bus tube
    channel.
  - Group the MembersChanged signals for the initial roster
    (fdo#40933). This improve login performance.
  - Spec upgraded to 0.23.4 except for draft call interfaces.
    Mixins implement the new additions.
  - TpDBusPropertiesMixin now has a method for emitting the
    standard PropertiesChanged signal; in conjunction with
    the code generator, it respects the EmitsChangedSignal
    annotation.
  + Fixes:
  - Python examples now works with latest pygobject.
* Wed Sep 28 2011 zaitor@opensuse.org
- Changed BuildRequires from vala-devel to vala, as vala-devel
  is an old deprecated name.
* Thu Aug 18 2011 dimstar@opensuse.org
- Update to version 0.15.5:
  + Enhancements:
  - A new pair of classes, TpSimpleClientFactory and
    TpAutomaticClientFactory, have been added.
  - A new TpAccount feature, TP_ACCOUNT_FEATURE_CONNECTION, has
    been added, to ask TpAccount to prepare TpConnection objects
    before announcing them.
  - TpConnection now has API for managing the user's contact list
  - fdo#26516: Add tp_debug_sender_set_timestamps.
  - A metric tonne of new methods were added for joining chat
    rooms and managing members.
  - TpFileTransferChannel, a high-level API for file transfer
    channels, was added.
  - fdo#38061: tp_cm_message_set_message() was added to
    complement tp_cm_message_take_message().
  + Fixes:
  - fdo#38060: fix a crash caused by an off-by-one error when
    constructing the SendError signal.
  - fdo#38997: cope more gracefully if UNIX sockets are
    unsupported, which should improve Windows portability.
  - fdo#39377: TpContact no longer erroneously re-prepares many
    features if existing contacts are re-requested.
  - fdo#27855: TpChannelManagers now have access to the original
    TargetID specified in the channel request,
  + Updated translations.
* Tue Jul 12 2011 dimstar@opensuse.org
- Update to version 0.15.4:
  + Fixes:
  - fdo#29172: TpTextChannel never finishes preparing if there
    are pending messages with no message-sender-id.
  - fdo#38997: Cope better if UNIX sockets are unsupported.
  - Fix some compiler warnings.
* Sat Jul  9 2011 dimstar@opensuse.org
- Update to version 0.15.3:
  + Enhancements:
  - fdo#38559: TpTextChannel:
    tp_text_channel_ack_all_pending_messages_async: convenient
    function to easily ack all the pending messages.
  - fdo#38605: TpChannelRequest: add properties and accessors for
    Account, UserActionTime and PreferredHandler
    preferred-handler and user-action-time.
  - TpAccountChannelRequest and TpBaseClient: API to use the
    DelegateToPreferredHandler hint.
  - TpMessage: tp_message_get_pending_message_id: convenient
    function to get the pending-message-id of the message.
  - TpChannel: Annotate tp_channe_group_ methods.
  + Fixes:
  - Fix some set-but-not-used warnings with --disable-debug.
  - Honor NOCONFIGURE for compatibility with gnome-autogen.sh.
  - Fix tests failing on some arch.
  - fdo#38944: Fix memory leaks in TpConnection.
* Wed Jun 22 2011 dimstar@opensuse.org
- Update to version 0.15.2:
  + Enhancements:
  - Reduce debug spam.
  - tp_channel_destroy_async(): high level API to Destroy a
    TpChannel.
  - tp_channel_dispatch_operation_{leave,destroy}_channels_async:
    convenience API to claim a ChannelDispatchOperation and
    leave/destroy all its channels. [fdo#28015]
  - TpChannel: high level API for password protected channels;
    the TP_CHANNEL_FEATURE_PASSWORD feature is automatically
    prepared by TpAutomaticProxyFactory. [fdo#37360]
  - TpConnection high level avatars API and TpChannel high level
    group API are now introspected.
  + Fixes:
  - TpChannelIface: set TP_UNKNOWN_HANDLE_TYPE as default handle
    type. [fdo#38524]
* Mon May 30 2011 dimstar@opensuse.org
- Update to version 0.15.1:
  + Fixes:
  - tp_text_channel_set_chat_state_finish: check the right
    source tag.
  - TpConnection: set the self handle to something sane instead
    of leaving uninitialized.
  - fdo#37280: Fix a race condition
  + Enhancements:
  - fdo#36334: TpTextChannel: high level API for SMS; the
    TP_TEXT_CHANNEL_FEATURE_SMS feature is automatically prepared
    by TpAutomaticProxyFactory.
  - fdo#36334: TpConnection: high level API for Balance.
  - fdo#28015: tp_channel_dispatch_operation_close_channels_async
    convenient API to claim a ChannelDispatchOperation and close
    all its channels.
  - fdo#35331: TpBaseContactList: add ContactBlocking support.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 0.15.0:
  + Update to spec 0.23.2:
  - Generated code for Channel.Interface.SMS.GetSMSLength()
  - Generated code for ChannelDispatcher.DelegateChannels() and
    ChannelDispatcher.PresentChannel()
  + tp_channel_dispatch_operation_claim_with_async() replacing
    tp_channel_dispatch_operation_claim_async() [fdo#36490]
  + TpProxyFeature is now part of the API allowing users to define
    their own features [fdo#31583]
  + Add tp_base_client_delegate_channels_{async,finish} and
    tp_channel_dispatcher_present_channel_{async,finish}: high
    level API to delegate and present channels [fdo#34610]
  + TpChannelDispatcher is now exported in the GIR file and so can
    be used using gobject-introspection
- Changes from version 0.14.6:
  + tp_dbus_daemon_watch_name_owner leaked a DBusMessage
  + tp_dbus_daemon_list[_activatable]_names leaked a DBusMessage
  + tp_base_connection_change_status: delay side-effects until all
    preconditions are checked
  + TpGroupMixin: correctly use contact-ids, not member-ids
  + TpBaseContactList: fix leak of source object.
* Mon May  2 2011 vuntz@opensuse.org
- Update to version 0.14.5:
  + Enhancements:
  - Update to spec 0.22.2, generating code for the
    Balance.ManageCreditURI and
    SimplePresence.MaximumStatusMessageLength properties.
  - tp_base_client_is_handling_channel(), which does what it says
    on the tin.
  - TpPresenceMixin now supports the MaximumStatusMessageLength
    class.
  + Fixes:
  - The documentation now builds correctly with gtk-doc 1.16 and
    newer.
  - The test suite now passes on systems with glib-networking
    installed.
- Changes from version 0.14.4:
  + Enhancements:
  - fdo#27459: TpConnection now avoids a bunch of redundant D-Bus
    method calls when preparing the CORE feature with recent
    services, lowering latency
  - tp_proxy_add_interfaces() for adding discovered interfaces
    from TpProxy subclasses
  - tp_base_protocol_get_immutable_properties() now fills the
    Proto.I.Avatars properties
  + Fixes:
  - fdo#36134: TpProtocol claims it doesn't support any extra
    iface
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 0.14.3:
  + Update to spec 0.22.1:
  - Generated code for new StreamHandler methods and signals and
    types.
  - TP_ERROR_INSUFFICIENT_BALANCE.
  + tp_g_ptr_array_extend() for concatenating two GPtrArrays.
* Mon Apr  4 2011 dimstar@opensuse.org
- Use vala-devel BuildRequires instead of vala-unstable-devel (vala
  0.12 has been released).
* Tue Mar 22 2011 fcrozat@novell.com
- Update to version 0.14.1:
  + Update to spec 0.22.0:
  - TP_PROP_CHANNEL_TYPE_SERVER_TLS_CONNECTION_REFERENCE_IDENTITIES
  - generate code for Connection.I.ContactBlocking
- Changes from version 0.14.0
  + The error handling code paths when looking up the senders of
    incoming messages have been fixed. This issue led to
    TpSignalledMessages not specifying a sender with CMs that omit
    sender-id, like telepathy-idle.
* Wed Mar 16 2011 fcrozat@novell.com
- Update to version 0.13.18:
  + Previously, tp_clear_object (NULL), tp_clear_boxed (type, NULL)
    and tp_clear_pointer (NULL) were no-ops. However, this
    behaviour was not very useful—these functions are always called
    as tp_clear_object (&priv->foo) in practice—and triggered
    compiler warnings (because these are actually implemented as
    macros). Thus, this usage is no longer supported.
  + Fixes:
  - TpCMMessage is no longer included in the .gir file. This
    class is only useful in CMs; we only support client-side API
    in the .gir file.
  - Correctly include TpBasePasswordChannel documentation.
  - Fix GCC 4.6 and Clang analyzer warnings
- Changes from version 0.13.17:
  + Update to spec 0.21.11:
  - TP_ERROR_STR_SOFTWARE_UPGRADE_REQUIRED
  - TP_ERROR_STR_EMERGENCY_CALLS_NOT_SUPPORTED
* Wed Mar  9 2011 fcrozat@novell.com
- Update to version 0.13.16:
  + Enhancements:
  - Update to spec 0.21.11:
    . TP_PROP_CLIENT_OBSERVER_DELAY_APPROVERS
  - Two new functions,
    tp_connection_get_connection_manager_name() and
    tp_connection_get_protocol_name(), allow you to grab these
    properties from a TpConnection without having to drive
    tp_connection_parse_object_path() yourself.
  - GBinding utilities for connection-status on TpAccount and
    TpConnection:
    tp_connection_bind_connection_status_to_property() and
    tp_account_bind_connection_status_to_property().
  - TpTextChannel now has a "message-types" property and
    accessor. It also gained
    tp_text_channel_supports_message_type() a convenient
    function to check if a specific message type is supported.
  - TpContactSearch: only close channels if there was an error
  - TpBaseClient gained
    tp_base_client_set_observer_delay_approvers() which can be
    used to indicate that an Observer has to block Approvers.
  + Fixes:
  - Various crashes fixed in TpBaseContactList.
* Fri Feb 25 2011 fcrozat@novell.com
- Update to version 0.13.15:
  + Enhancements:
  - Update to spec 0.21.10.
  - tp_utf8_make_valid(): an UTF-8 string validation function.
  - SimplePasswordManager now has API to let the CM create its
    own SASL channel.
  - TpBasePasswordChannel: a base class to implement SASL
    channels.
- Changes from version 0.13.14:
  + Enhancements:
  - TpContact now supports modifying the contact's groups on
    connection managers which implement
    Connection.Interface.ContactGroups.
  - It's now possible to get a list of TpChannelRequest objects
    from a TpObserveChannelsContext or TpHandleChannelsContext;
    adding hints to channel requests, and retrieving them again,
    is supported with telepathy-mission-control ≥ 5.7.2.
  - tp_account_channel_request_create_and_observe_channel_async()
    and friends, analogous to
    tp_account_channel_request_create_and_handle_channel_async()
    but for Observers rather than Handlers, have been added.
  - Code is now generated to emit and listen for the
    PropertiesChanged signal on org.freedesktop.DBus.Properties.
    Note that TpDBusPropertiesMixin does not emit this signal on
    it own, nor does TpProxy listen for it of its own accord.
  - tp_capabilities_supports_room_list(), a convenient way to
    check whether a connection supports listing chat rooms, has
    been added.
  + Fixes:
  - Including telepathy-glib/protocol.h now correctly includes
    generated client-side functions.
- Changes from version 0.13.13:
  + Many doc fixes
  + Compiler flags reordered (clang is order-sensitive) to allow
    static analysis.
  + Account Channel Requests now give you access to the originating
    TpChannelRequest.
  + The speculative debug cache may now be disabled at compile time.
- Changes from version 0.13.12:
  + Enhancements:
  - TpContact now tracks incoming and outgoing presence
    subscriptions, albeit only if the connection implements the
    new Connection.Interface.ContactList API.
  - Code is generated for new API added in telepathy-spec
    version 0.21.9; specifically, the FileTransfer.URI property
    is supported.
  - TpPresenceMixinStatusAvailableFunc, which has confused many
    a CM author, now has clearer documentation.
  + Fixes:
  - We no longer accidentally depend on GLib 2.28.
  - tests/contact-search-result no longer fails on x86.
- Changes from version 0.13.11:
  + Enhancements:
  - fdo#32053: The TpContactSearch object has been added. It
    represents ongoing searches for contacts.
  + Fixes:
  - fdo#32551: tp_base_client_set_observer_recover now works
    with all possible gboolean arguments!
  - tp_debug_timestamped_log_handler will now print the message
    and not just the time, which was broken over a year ago.
  - TpProtocol will now consider a manager file's
    AuthenticationTypes value.
- Change vala-devel BuildRequires to vala-unstable-devel.
* Sun Jan 30 2011 fcrozat@novell.com
- Changes from version 0.13.10:
  + Enhancements:
  - New TpMessage API: tp_message_get_message_type,
    tp_cm_message_new_text
  - fdo#32411: warn and do nothing if unsupported flags are
    passed to tp_g_signal_connect_object
  + Updated to spec 0.21.8.
  - The ContactList.ContactsChangedWithID signal was added. It's
    automatically emitted by TpBaseContactList, so CMs don't
    need to make any changes to take advantage of it.
  + Fixes:
  - tp_account_manager_ensure_account() no longer criticals if
    you pass it a malformed account path.
  - TpBaseClient will now return (an error) from ObserveChannels
    if an invalid connection path is passed to it by the Channel
    Dispatcher.
  - fdo#32184: Connection bus names are no longer erroneously
    released while connections are still open. This was a
    regression in 0.13.5.
  - fdo#32423: Preparing TpAccount features when the CORE
    feature is already prepared now works
  - fdo#32391: correctly deal with removing name owner watches
    during dispatch of their callbacks
  - Documentation improvements
  - TpBaseClient no longer breaks if HandleChannels is called
    more than once for the same channel. This was a regression
    introduced by the leak fix in the previous release.
- Changes from version 0.13.9:
  + Deprecations:
  - tp_message_new (replace with tp_cm_message_new)
  - tp_message_ref_handle (no longer needed)
  - tp_message_set_handle (use tp_cm_message_set_sender for the
    only supported handle in a message)
  - tp_message_take_message (replace with
    tp_cm_message_take_message)
  + Enhancements:
  - tp_account_get_path_suffix: new function to get the varying
    suffix of an account's object path
  - TpAccountManager: document which TpAccount objects are
    prepared
  - tp_connection_dup_contact_if_possible: new function to make
    TpContact objects synchronously in some situations
  - convert TpMessage into a GObject, with subclasses for use in
    CMs (TpCMMessage) and clients (TpClientMessage,
    TpSignalledMessage)
  - add TpConnection:self-contact, a TpContact for the
    self-handle
  + Fixes:
  - In TpSimplePasswordManager, clear the pointer to the channel
    when it's closed
  - fdo#32116: don't leak LegacyProtocol object references
    when a TpBaseConnectionManager is registered
  - Fix an unlikely crash in which a TpBaseConnection outlives
    its TpBaseConnectionManager
  - Documentation improvements
  - fdo#32191: when tp_connection_get_contacts_by_handle would
    return contacts that already exist, make sure they have the
    desired features
  - Fix memory leaks in TpAccount and TpDynamicHandleRepo
    introduced in 0.13.8
  - fd.o #32222: fix a leak of TpChannel objects in
    TpBaseClient, document that Handlers are responsible for
    closing their channels, warn if channels are still handled
    when a Handler is disposed, and close channels in some
    regression tests
- Changes from version 0.13.8:
  + Deprecations:
  - fd.o #24114: tp_get_bus() is deprecated (again). Please use
    tp_dbus_daemon_dup(), followed by
    tp_dbus_daemon_register_object() if that's what you're using
    it for, or tp_proxy_get_dbus_connection() if you really need
    a DBusGConnection.
  + Changes:
  - fd.o #23155: handles now persist until the TpBaseConnection
    disconnects, and most of the reference-counting machinery
    has been removed
  - fd.o #31997: in the ContactList channels produced by
    TpBaseContactList, AddMembers, RemoveMembers etc. don't
    return until the implementation reports success or failure
  + Enhancements:
  - Update to spec 0.21.6.
  - fd.o #31900: add TpSimplePasswordManager
  - fd.o #32004: add tp_account_get_automatic_presence,
    tp_account_get_normalized_name,
    tp_account_set_automatic_presence_async
  - fd.o #31918: add convenience API for Account.I.Addressing
  + Fixes:
  - return a zero-terminated array of features from
    tp_client_channel_factory_dup_channel_features
  - fd.o #32004: emit GObject::notify for TpAccount::requested-*
- Changes from version 0.13.7:
  + Enhancements:
  - Update to spec 0.21.5.
  - fdo#31686: add Protocol.I.Avatars support to TpBaseProtocol
  - implement the MessageTypes property in the TpMessagesMixin
  - use G_N_ELEMENTS more
  + Fixes:
  - use the right getter for TpAccountChannelRequest:request
- Changes from version 0.13.6:
  + API changes:
  - Pointers to a GObject implementing
    TP_TYPE_CLIENT_CHANNEL_FACTORY are now referred to as having
    type TpClientChannelFactory*, rather than misusing
    TpClientChannelFactoryInterface*. The ABI has not changed.
  + Enhancements:
  - Return the reffed handle from tp_handle_ref()
  + Fixes:
  - fdo#31473: force the namespace TelepathyGLib for the
    g-i-derived Vala bindings
  - fdo#31581: don't modify a const array in
    tp_group_mixin_remove_members_with_reason
  - fdo#31631: set a TpBaseClient's TpClientChannelFactory
    correctly
  - fdo#31631: fix confusion between TpClientChannelFactory
    and TpClientChannelFactoryIface
  - Run the stream tube IPv6 tests again, if ::1 is assigned to
    an interface
- Changes from version 0.13.5:
  + Enhancements:
  - fdo#30088: add support for Protocol.I.Presence to
    TpBaseProtocol
  + Fixes:
  - fdo#10613: release connections' object paths before their
    bus names, and do both sooner
  - fdo#31377: fix a race condition in the
    connection-interests test that sometimes caused it to fail
    or segfault, and similar races (not seen in practice) in two
    other tests
- Changes from version 0.13.4:
  + Enhancements:
  - Update to spec 0.21.4
  - fdo#31215: fix incorrect namespace for MailNotification
  - add bindings for NewActiveTransportPair
  + Fixes:
  - fdo#31321: don't crash if the TpAccountManager is disposed
    while an account from tp_account_manager_ensure_account is
    preparing
  - fdo#31291: add pkg-config and C header information to GIR
    for the benefit of future Vala versions
  - In the echo2 example CM, advertise Messages' immutable
    properties
  - In TpBaseChannel, don't unref handles we didn't ref
- Changes from version 0.13.3:
  + Deprecations:
  - <telepathy-glib/debug-ansi.h> is now deprecated, and the
    Group and Properties mixins no longer output
    brightly-coloured logs
  + Enhancements:
  - fdo#31102: update to spec 0.21.3.
  - fdo#27948: add generic support for AddClientInterest,
    RemoveClientInterest on TpBaseConnection and TpConnection
  - fdo#30505: add TpDTMFPlayer, a DTMF dialstring interpreter
  - TpClientChannelFactory: ask callers to prepare a given set
    of features, and do so in TpBaseClient
  + Fixes:
  - fdo#30730: order tests' and examples' CFLAGS and LIBS
    consistently, fixing builds in some situations (an older
    telepathy-glib built with -rpath already installed,
    possibly)
  - fdo#30949: fix a typo that made DeliveryReportingSupport
    always come out as 0, and test a nonzero value
  - Don't leak an array of features in TpBaseClient
  - fdo#31027: if stdout is a tty, tests now succeed silently,
    and only produce output on failure; also, they will
    automatically fail after a few seconds if an expected event
    does not happen
  - fdo#30999: tests now succeed on machines where IPv6 is
    supported but ::1 is not assigned to an interface
- Changes from version 0.13.2:
  + Enhancements:
  - Update to spec 0.21.2
  - fdo#29973: add TpClientChannelFactory,
    TpAutomaticProxyFactory and TpBasicProxyFactory, and use
    them in TpBaseClient and TpAccountChannelRequest
  - fdo#29218: add TpStreamTubeChannel, a higher-level API for
    stream tubes
  - fdo#30478: add TP_ACCOUNT_FEATURE_STORAGE
  - Improve the error message for an undefined D-Bus interface
  + Fixes:
  - fdo#30791: fix building with gtk-doc enabled, and an older
    telepathy-glib installed in a non-default library search
    path
  - fdo#30644: don't 'return' a void expression from a void
    function, which isn't valid C99 and breaks compilation on
    Sun Studio C
  - Remove redundant trailing semicolons from G_DEFINE_TYPE
    etc., which are not valid C99
  - Add DeliveryReportingSupport to the properties offered by
    TpMessageMixin
  - Add ContactListState to the properties offered by
    TpBaseContactList
  - Avoid using a gboolean (which is signed) as a one-bit
    bitfield
- Changes from version 0.13.1:
  + Enhancements:
  - Update to spec 0.21.1.
  + Fixes:
  - In TpCapabilities, do more checks on the self pointer
- Changes from 0.13.0:
  + Enhancements:
  - Update to spec 0.21.0.
  - fdo#28200: add TpBaseContactList, a base class for contact
    list/contact groups implementations
  - fdo#30204: add checks for stream and D-Bus tubes to
    TpCapabilities
  - fdo#30327: add some new utility functions for TpHandleSet
  - fdo#30310: make tp_contacts_mixin_get_contact_attributes
    public for re-use
  - debug-log the error message when a Protocol filter rejects a
    parameter
* Tue Dec 21 2010 vuntz@opensuse.org
- Update to version 0.12.7:
  + Fixes:
  - tp_account_manager_ensure_account() no longer criticals if
    you pass it a malformed account path.
  - TpBaseClient will now return (an error) from ObserveChannels
    if an invalid connection path is passed to it by the Channel
    Dispatcher.
  - fdo#32391: correctly deal with removing name owner watches
    during dispatch of their callbacks
* Tue Dec 14 2010 vuntz@opensuse.org
- Update to version 0.12.6:
  + Fixes:
  - fdo#32116: don't leak LegacyProtocol object references when a
    TpBaseConnectionManager is registered
  - Fix an unlikely crash in which a TpBaseConnection outlives
    its TpBaseConnectionManager
  - fdo#32191: when tp_connection_get_contacts_by_handle would
    return contacts that already exist, make sure they have the
    desired features
  - fdo#32222: fix a leak of TpChannel objects in TpBaseClient,
    document that Handlers are responsible for closing their
    channels, warn if channels are still handled when a Handler
    is disposed, and close channels in some regression tests
* Fri Nov 26 2010 dimstar@opensuse.org
- Update to version 0.12.5:
  + Use the right getter for TpAccountChannelRequest:request.
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 0.12.4:
  + Fixes:
  - fdo#31473: force the namespace TelepathyGLib for the
    g-i-derived Vala bindings
  - fdo#31581: don't modify a const array in
    tp_group_mixin_remove_members_with_reason
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 0.12.3:
  + fdo#31321: don't crash if the TpAccountManager is disposed
    while an account from tp_account_manager_ensure_account is
    preparing
  + fdo#31198: avoid some C99 features not supported by MSVC 9
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 0.12.2:
  + Fixes:
  - fdo#30730, fdo#30791: order tests' and examples' CFLAGS and
    LIBS consistently, fixing builds in some situations (an older
    telepathy-glib built with -rpath already installed, possibly)
  - fdo#30949: fix a typo that made DeliveryReportingSupport
    always come out as 0, and test a nonzero value
  - Don't leak an array of features in TpBaseClient
* Mon Oct 18 2010 vuntz@opensuse.org
- Update to version 0.12.1:
  + Enhancements:
  - When a Protocol's filter rejects a parameter, log the error
    message
  - Improve the error message for an undefined D-Bus interface
  - Check the GObject type of the self pointer in TpCapabilities
    methods
  + Fixes:
  - fdo#30644: don't 'return' a void expression from a void
    function, which isn't valid C99 and breaks compilation on Sun
    Studio C
  - Remove redundant trailing semicolons from G_DEFINE_TYPE etc.,
    which are not valid C99
  - Add DeliveryReportingSupport to the properties offered by
    TpMessageMixin
  - Avoid using a gboolean (which is signed) as a one-bit
    bitfield
* Tue Sep 21 2010 dimstar@opensuse.org
- Update to version 0.12.0:
  + Disable documentation completeness checks and redirect
    documentation uploads for stable branch
  + Add the version number, and a link to the latest version, to
    the documentation
  + Increase dependencies for Vala bindings to versions that the
    libfolks developers have verified to work:
    gobject-introspection 0.9.6 and Vala 0.10.0.
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 0.11.16:
  + Enhancements:
  - Update to stable spec 0.20.1
    . generate basic API for Chan.I.Conference
    . generate basic API for Chan.T.ServerTLSConnection and
    TLSCertificate (server-side only for now, since
    TLSCertificate will require a new TpProxy subclass)
  - When connections are created in a CM, debug-log the sanitized
    parameter values
  - When a TpBaseChannel is created, log an error if it doesn't
    have a parent connection
  + Fixes:
  - fdo#30134: rename TpIntSet to TpIntset, with compatibility
    typedefs for the old name, to avoid breaking recent
    gobject-introspection
  - fdo#30134: add more gobject-introspection annotations to work
    better with recent versions, and work around another case of
    (skip) not working in older versions
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 0.11.15:
  + Enhancements:
  - Update to spec 0.19.12:
    . generate code for SMS interface for Text channels, NotYet
    error, Object_Immutable_Properties type and
    TP_PROP_CONNECTION_INTERFACE_CELLULAR_OVERRIDE_MESSAGE_SERVICE_CENTRE
  - fdo#28420: add tp_channel_get_requested() etc.
  - Add basic introspectability for the Connection mixins
  + Fixes:
  - fdo#30090: fix parsing TpProtocol information from .manager
    files
  - fdo#29943: make tp_debug_sender_log_handler thread-safe
  - fdo#30111: make GObject-Introspection work again with g-i >=
    0.9.5
  - fdo#30134: make configure fail if Vala bindings are enabled
    but g-i is disabled, which can't work
  - fdo#25582, fdo#27806, fdo#30118: fix miscellaneous memory
    leaks
* Thu Aug 26 2010 dimstar@opensuse.org
- Update to version 0.11.14:
  + Enhancements:
  - fdo#29375: there's now a TpBaseChannel class which deals with
    all the boring boilerplate previously needed to implement
    channels. Public response to the class has been uniform.
  - fdo#29614: add TpBaseClient:account-manager
  - Allow TpBaseClient instances to wait for any desired set of
    TpAccount, TpConnection and TpChannel features
  - fdo#29671: add TP_ARRAY_TYPE_UCHAR_ARRAY_LIST, i.e. signature
    'aay' in dbus-glib
  + Fixes:
  - Ensure that when a TpAccountChannelRequest produces a
    connection and a channel, they're obtained from the same
    TpAccount we started from
  - fdo#29756, fdo#29795: various documentation improvements.
* Wed Aug 18 2010 dimstar@opensuse.org
- Update to version 0.11.13:
  + Changes to experimental API:
  - fdo#29070: remove telepathy-vala.pc
  + Enhancements:
  - fdo#29358: add TP_ERROR as an alias for TP_ERRORS, for
    introspectability
  - add TP_USER_ACTION_TIME_NOT_USER_ACTION,
    TP_USER_ACTION_TIME_CURRENT_TIME,
    tp_user_action_time_from_x11,
    tp_user_action_time_should_present
  - improve various documentation
  - convert TpBaseClient virtual methods into normal GObject
    virtual methods so they can be introspected
  + Fixes:
  - Don't rely on vala-1.0.pc to check for vala version and
    vapigen
  - fdo#25019: let the TpPresenceMixin work on connections that
    implement SimplePresence but not complex Presence
  - Fix harmless misuse of enums that caused warnings on gcc 4.5
  - Fix out-of-tree builds with Vala enabled
- Replace pkgconfig(vala-1.0) BuildRequires with vala-devel one
  since we want the vala compiler, not libvala.
* Wed Aug 11 2010 vuntz@opensuse.org
- Update to version 0.11.12:
  + Enhancements:
  - Added TpAccountChannelRequest, a request to create or ensure
    a channel (fdo#29456, fdo#13422)
  - fdo#29461: updated to telepathy-spec 0.19.11
    . more error codes for SSL/TLS - Insecure, Revoked,
    LimitExceeded
    . Conference_Host call state flag
  + Fixes:
  - fdo#29174: update example connection managers to follow
    current telepathy-spec best practices, including Protocol
    objects
  - fdo#29268: fix compilation from a tarball with
  - -enable-vala-bindings
- Remove manually added telepathy-glib.deps: it's in the tarball
  now.
* Sat Aug  7 2010 vuntz@opensuse.org
- Add pkgconfig(vala-1.0) BuildRequires and pass
  - -enable-vala-bindings to configure: we need telepathy-vala for
  the folks package.
- Add vala/telepathy-glib.deps manually, since it's missing from
  the tarball.
* Thu Jul 29 2010 dimstar@opensuse.org
- Update to version 0.11.11:
  + Enhancements:
  - Updated spec to 0.19.10
    . generate code for Protocol objects, and the ContactSearch
    channel type
  - fdo#27997: add TpProtocol client-side API, and TpBaseProtocol
    service-side base class, for Protocol objects
  - fdo#28751: tp_proxy_has_interface is now a real function, not
    a macro, for better introspection
  - TpBaseClient's properties now have accessor methods for
    convenient use in C
  - tp_capabilities_get_channel_classes is now visible to g-i
  + Fixes:
  - Install a .deps file for the Vala bindings
  - Vala bindings now install to the normal location, making it
    unnecessary to look up telepathy-vala in pkg-config; that
    pkg-config file will be removed in a future version
  - fdo#29197: expand g-i coverage of connection manager code
    enough to use it for libfolks' regression tests.
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 0.11.10:
  + Enhancements:
  - Updated spec to 0.19.9:
    . added support for Read and Deleted delivery reports
  + Fixes:
  - Improved GObject-Introspection annotations to be sufficient
    for libfolks
  - Fixed a typo in the documentation
  - fdo#28920: fixed tp_contact_request_contact_info_async
    cancellation handling when dealing with synchronous errors
- Changes from version 0.11.9:
  + Enhancements:
  - Updated spec to 0.19.8:
    . generate code for some new properties, Conn.I.Cellular and
    Account.I.Storage
    . add convenience methods to TpAccount to access
    Account.Service
  - Added tp_simple_async_report_success_in_idle, a convenience
    function to return "void" from an async method
  + Fixes:
  - Fixed libdbus errors when unregistering a TpBaseClient that
    isn't a Handler
  - Made some TpGroupMixin methods more const-correct
  - Fixed some memory leaks in regression tests
  - Suppressed more valgrind false-positives
  - Improved generation of experimental Vala bindings
* Wed Jul 21 2010 vuntz@opensuse.org
- Clean up update to 0.11.8.
- Drop work_around_pkg_config.patch: not needed anymore.
- Change dbus-1-glib-devel BuildRequires to pkgconfig()
  BuildRequires: dbus-1, dbus-glib-1, gobject-2.0, gio-2.0,
  gio-unix-2.0.
- Add pkgconfig(gobject-introspection-1.0) to enable introspection
  support.
- Remove explicit dbus-1-glib-devel and glib2-devel Requires in
  devel package, since pkgconfig() Requires are now automatically
  added.
* Tue Jun 22 2010 dimstar@opensuse.org
- Update to version 0.11.8:
  + Enhancements:
  - Improve GObject-Introspection annotations, and optionally
    build Vala bindings, which are currently considered highly
    experimental
  + Various fixes
- Changes from version 0.11.7:
  + Deprecations:
  - TpChannelFactoryIface is officially deprecated (it shouldn't
    have been used since 0.8).
  - tp_verify() should not be used in new code: use GLib 2.20's
    G_STATIC_ASSERT.
  + Enhancements:
  - Update to telepathy-spec 0.19.7
    . generate code for the Anonymity and ServicePoint interfaces
    . add ChatStates property and Chat_State_Map type
    . add Account.ConnectionError and ConnectionErrorDetails
    properties
  - API additions
  - speed up and cleanup regression tests
  + Various fixes
- Changes from version 0.11.6:
  + Enhancements:
  - Updated to telepathy-spec 0.19.6:
    . ChangingPresence property on the Account interface
    . SupportedLocationFeatures property on the Location
    interface
    . HandleWithTime method on ChannelDispatchOperation
    . MultipleTones method, SendingTones and StoppedTones
    signals, and CurrentlySendingTones and InitialTones
    properties on the DTMF interface
  - API additions
  - Make the ContactList example connection manager more
    realistic, and add a regression test for it
  + Fixes:
  - fdo#28203: TpGroupMixin: allow "adding" contacts who are
    already members, even if the Can_Add flag isn't set (e.g.
    accepting a subscription request twice), and allow "removing"
    contacts who are not in the channel (e.g. rejecting a
    subscription request twice)
  - minor fixes
- Changes from version 0.11.5:
  + API changes:
  - fdo#23369: when the local user is removed from a Group
    Channel, the GError with which the TpChannel is invalidated
    has changed.
  + Enhancements:
  - API additions
  + Various fixes
- Changes from version 0.11.4:
  + Enhancements:
  - Add experimental GObject-Introspection bindings
  - API additions
  + Various fixes
- Changes from version 0.11.3:
  + Enhancements:
  - Upgrade to telepathy-spec 0.19.5
    . Connection.Status, Connection.Interfaces properties (all
    telepathy-glib CMs that use TpBaseConnection should gain
    support for these automatically)
    . Observer.Recover property
    . ContactInfo interface
  - API additions
  + Various fixes
- Changes from version 0.11.2:
  + Undeprecate tp_get_bus()
- Changes from version 0.11.1:
  + Enhancements:
  - API additions
  + Various fixes
- Changes from version 0.11.0:
  + Deprecations:
  - all re-entrant functions
  - tp_get_bus()
  + Enhancements:
  - Update to telepathy-spec 0.19.3
    . generate code for new Connection.Interfaces,
    Connection.Status properties, and implement them in
    TpBaseConnection
    . generate code for Connection.Interface.Balance
  - API additions
  - Add an example connection manager for the experimental Call
    API that will eventually replace StreamedMedia
  + Various fixes
- Rebase work_around_pkg_config.patch.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.10.6:
  + TpGroupMixin: allow "adding" contacts who are already members,
    even if the Can_Add flag isn't set
  + TpGroupMixin: allow "removing" contacts who are not in the
    channel
  + Correct the syntax of TP_IS_HANDLE_REPO_IFACE
* Wed May 12 2010 dimstar@opensuse.org
- Update to version 0.10.5:
  + Enhancements:
  - fdo#27794: improve regression test coverage for TpAccount
  + Fixes:
  - fdo#27780: when TpAccount:connection changes, emit
    notify::connection (smcv)
  - Don't leak TpAccount:parameters when disposed
  - Fix more assertion failures (this time in TpContact) if
    getting contact attributes fails or yields the wrong type
  - Remove some dead code to keep coverity happy
- Changes from version 0.10.4:
  + Fixes:
  - fdo#27714: support G_CONNECT_AFTER in
    tp_g_signal_connect_object, and document exactly which flags
    we support
  - fdo #27537: fix assertion failure if getting contact
    attributes fails
* Sat Apr 24 2010 coolo@novell.com
- add work around for missing provides
* Wed Apr  7 2010 vuntz@opensuse.org
- Update to version 0.10.3:
  + Fixes:
  - Don't fail 'make check' if gtk-doc complains that the
    documentation is incomplete, since this is a stable branch,
    but gtk-doc's definition of "complete" changes from release
    to release
  - Don't warn/error if we're using deprecated functions, since
    this is a stable branch, so it's not going to be fixed here
  + Documentation:
  - fdo#27281: clarify documentation for tp_message_mixin_sent,
    using telepathy-spec 0.19.2 as a reference
  - Improve documentation of
    TpContactsMixinFillContactAttributesFunc
  - tp_account_set_nickname_async: set the right source_tag
* Fri Apr  2 2010 vuntz@opensuse.org
- Update to version 0.10.2:
  + Fixes:
  - TpAccount: correctly add interfaces such as Avatars
  - Make GetContactAttributes() in GLib CMs tolerate unsupported
    interfaces, as per telepathy-spec 0.19.2
  - Improve documentation of
    TpContactsMixinFillContactAttributesFunc
* Thu Mar 25 2010 vuntz@opensuse.org
- Update to version 0.10.1:
  + Fixes:
  - Don't make an idle call to put received messages in the
    TpMessageMixin queue, potentially avoiding a reference leak
  - tp_contacts_mixin_set_contact_attribute now takes a const
    gchar * instead of a gchar *
  - Escape the doc-comments better in generated service
    interfaces
  - Fix some typos and broken cross-references in the
    documentation, and improve the TpAccount documentation
  - Chain up to GObject's dispose method when destroying a
    TpBaseConnectionManager
  - Remove a misleading debug message from
    tp_list_connection_names
* Fri Jan 22 2010 vuntz@opensuse.org
- Update to version 0.10.0:
  + Enhancements:
  - Add compile-time warnings if the results of functions that
    allocate memory are ignored.
  - Add compile-time warnings if the results of certain functions
    with no side-effects are ignored.
  - Improve lcov.am, syncing with telepathy-gabble
  + Fixes:
  - fdo#23848: when making a release, make the build system check
    for files that indicate unreleased status; correct a few such
    comments
  - fdo#25149: when a TpAccount is invalidated (deleted), signal
    connection disconnection first
  - Exit the main loop gracefully when CMs are disconnected from
    the session bus
  - fdo#14603: don't set fatal criticals in
    tp_run_connection_manager, CMs are now responsible for doing
    this
  - fdo#25600: fix inadvertant GLib 2.20 dependency
  - In code generation tools (glib-ginterface-gen.py), allow
    D-Bus methods whose names are C keywords
  - Fix with-session-bus.sh dbus-monitor logging when /bin/sh is
    not bash
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 0.9.2:
  + Enhancements:
  - Add tp_value_array_build utility function
  - Add tp_g_signal_connect_object, a non-leaky version of
    g_signal_connect_object
  - fdo#25283: add constants for namespaced D-Bus property names,
    such as TP_PROP_CHANNEL_CHANNEL_TYPE
  - fdo#25235: add <telepathy-glib/telepathy-glib.h> which
    includes the most commonly-used headers
  + Fixes:
  - fdo#24257: make sure tp_account_prepare,
    tp_account_manager_prepare will fail if the object is
    invalidated, rather than never finishing
  - fdo#25051: fix a use-after-free in TpAccountManager by
    disconnecting signal handlers on destruction
  - fdo#24654: fix a potential use-after-free in TpAccount and
    TpAccountManager by copying the list of features required
  - Future-proof TpAccount and TpAccountManager to allow more
    than one Feature
  - fdo#24394: improve code portability to Windows headers and
    compilers
  - fdo#25121: fix failure to link when -Wl,--no-add-needed is
    used, which is the (faster) default behaviour for
    binutils-gold (deb#556486)
  - Fix various coverity nits, including a missing call to
    va_end, and a typo in the documentation
  - fdo#25359: alter code generation to cope with arbitrary UTF-8
    in the spec
  - fdo#25335: glib-client-gen: annotate deprecated D-Bus methods
  - Don't rely on enum types being unsigned
  - fdo#25181: avoid unnecessary D-Bus calls re-fetching existing
    TpContact objects
  - fdo#25384: if accounts fail to prepare while the account
    manager is preparing, drop them from the list of valid
    accounts rather than never terminating
  - If the fake AccountManager doesn't appear for some reason
    during AM regression tests, don't start the system
    implementation
  - Fix a theoretical reference-leak in TpAccountManager, and
    some memory leaks in examples and regression tests
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 0.9.1:
  + Fixes:
  - Corrected the GLib dependency to 2.20
  - Corrected the error message given when a write-only D-Bus
    property is read
  - Work around GLib 2.20 being less const-correct than 2.22
  - fdo#23853: if a connection manager is discovered not to be
    running while TpConnectionManager has a ListProtocols call
    in-flight, then a new instance of the CM starts up and
    replies to that call, don't crash with an assertion failure
  - If a connection manager returns error from GetParameters(),
    don't dereference a NULL pointer and segfault
  - When asked to activate or introspect a connection manager,
    don't do anything until we have at least worked out whether
    it was initially running, in order to provide the documented
    behaviour
  - When getting parameter details from a running connection
    manager, consider parameters called "password" or ending with
    "-password" to be secret even if they lack the SECRET flag,
    as was already done when reading .manager files
- Changes from version 0.9.0:
  + Dependencies:
  - GLib 2.20 is now required.
  - telepathy-glib now links to GIO as well as GLib and GObject.
  + Enhancements:
  - TpAccountManager, TpAccount: add convenience API similar to
    libempathy's
  - telepathy-glib now uses Automake 1.11's "silent rules"
    feature for kernel-style output.
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 0.8.0:
  + spec: update from 0.17.28 to 0.18.0 (no real changes)
  + ContactList example CM: fix a crash during shutdown
  + StreamedMedia example CM: check for direction changes correctly
- Changes from version 0.7.37:
  + Enhancements:
  - Update to telepathy-spec 0.17.28
    . add ContactCapabilities interface
    . add InitialVideo, InitialAudio, ImmutableStreams properties
    to StreamedMedia
    . add TP_CHANNEL_CALL_STATE_FLAG_IN_PROGRESS
  - Set the debug domain for telepathy-glib to tp-glib/$category,
    e.g.  tp-glib/connection for TpConnection and TpBaseConnection
  + Fixes:
  - fdo#23843: make tp_debug_sender_log_handler with exclude=NULL
    include everything, rather than nothing
* Fri Sep  4 2009 vuntz@novell.com
- Update to version 0.7.36:
  + Enhancements:
  - Add TpDebugSender, along with the lower-level TpSvcDebug
    interface that it uses
  - Clarify when tp_proxy_signal_connection_disconnect is safe to
    call
  - Add support for simulating DTMF and Hold support in the
    'callable' example connection manager
  - fdo#21327: truncate the ChangeLog at version 0.6 to stop it
    being so huge, and force ISO date format
  + Fixes:
  - If the bus name for a Connection would be too long, hash the
    unique name provided by the CM, instead of crashing
  - fdo#23524: don't introspect a TpConnectionManager twice in
    parallel, avoiding an assertion failure
  - TpChannel: don't disconnect from a TpProxySignalConnection
    that's already gone, fixing a crash
  - tp_connection_manager_idle_read_manager_file: avoid using the
    TpConnectionManager after it may have been disposed
  - TpBaseConnection: Allow GetInterfaces() to succeed before
    CONNECTED
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 0.7.35:
  + API changes:
  - fdo#17751: TpBaseConnection no longer guarantees that the
    self-handle is set to 0 when the state changes to
    DISCONNECTED; instead, the self-handle remains valid until
    the connection is disposed, so that connection managers can
    use it during teardown.
  + Enhancements:
  - Add tp_dbus_daemon_list_names() and
    tp_dbus_daemon_list_activatable_names(), which are more
    efficient (and more const-correct) versions of the
    corresponding autogenerated tp_cli_dbus_daemon methods
  - Support the Hold interface in the "callable" example CM
  + Fixes:
  - Finally make tp_dbus_daemon_watch_name_owner bind to
    NameOwnerChanged selectively, for reduced wakeups.
  - Fix a memory leak in tp_dbus_daemon_watch_name_owner
  - fdo#9812: TpDynamicHandleRepo: use
    tp_dbus_daemon_watch_name_owner for reduced wakeups
  - In TpDynamicHandleRepo, if a client holds handles then
    immediately crashes, release those handles as soon as we find
    out that it's gone
  - fdo#22957: fix compilation in some non-gcc compilers
  - As per telepathy-spec 0.17.27, represent connection status
    reason NAME_IN_USE as TP_ERROR_CONNECTION_REPLACED or
    TP_ERROR_ALREADY_CONNECTED (as appropriate), not as
    TP_ERROR_NOT_YOURS, so that NotYours can safely be given
    special handling
- Changes from version 0.7.34:
  + Enhancements:
  - Updated to telepathy-spec 0.17.27
  * generate code for Connection.Interface.Location
  * omit Debug interface from code-generation for now: it will
    be enabled in a future release when we have reference
    client- and service-side implementations (possibly called
    TpDebugReceiver and TpDebugSender)
  * add more errors
  * generate code for Handler.Capabilities property
  - Add macros for static assertions (tp_verify, tp_verify_true,
    tp_verify_statement) to util.h
  - Make the allocation model for
    tp_dbus_properties_mixin_make_properties_hash part of our ABI
    guarantee
  - Add a GType macro TP_ARRAY_TYPE_OBJECT_PATH_LIST
  + Fixes:
  - fdo#23164: don't unref a NULL DBusMessage
  - Get tp_intset_iter_init and tp_intset_iter_reset into the
    documentation
  - Make omitted CM parameters that have a default
    indistinguishable from explicitly-passed parameters with that
    value, removing the need to specify the default in the
    Connection as well
  - fdo#22889: reduce introspection round-trips
  - Fix header guard in debug.h
  - fdo#18091: for interfaces with D-Bus methods, document how to
    write a complete interface init function
  - Fix a rare crash when a TpProxyPendingCall is cancelled
    before the DBusGProxyCall is provided
* Sun Jul 19 2009 vuntz@novell.com
- Update to version 0.7.33:
  + Fixed a test failure in test-params-cm on certain
    architectures, including powerpc and sparc
  + Fixed an assertion failure in TpConnection if StatusChanged to
    CONNECTED is followed immdiately by GetStatus returning
    CONNECTED
* Sat Jun 13 2009 vuntz@novell.com
- Update to version 0.7.32:
  + Enhancements:
  - fdo#22208: Updated to telepathy-spec 0.17.26
  - Added generated service-side bindings for AccountManager,
    Account, ChannelDispatcher, ChannelDispatchOperation,
    ChannelRequest and Client - Added minimal versions of
    TpAccountManager, TpAccount,
    TpChannelDispatcher, TpChannelDispatchOperation,
    TpChannelRequest and TpClient
  - fdo#22205: Added support for deprecating or removing _run_
    methods in code generation
  - Added flymake support
  - fdo#22230: Added support for byte ('y') parameters to CMs
  + Fixes:
  - Made sure _gen/error-str.h and .c end with a newline, fixing
    compilation with certain compilers
  - fdo#19741: Documented client-side handle reference counting
  - fdo#21977: Removed duplicate mention of media-interfaces.h in
    Makefile.am
  - fdo#22121: made tp_channel_dispose properly idempotent
  - Removed dead code for introspecting alias flags
  - fdo#22182: Fixed a potential use-after-free in the callable
    example CM
  + Release notes for projects using code generation:
  - After updating to this version of glib-client-gen.py, _run_
    methods will no longer be generated by default. To get the
    behaviour of older versions, run it with the new
  - -generate-reentrant option; to get the methods present but
    deprecated, use an option like
  - -deprecate-reentrant=FOO_DISABLE_DEPRECATED (which means the
    _run_ methods are marked with G_GNUC_DEPRECATED, and will not
    be available at all if FOO_DISABLE_DEPRECATED is defined).
* Wed May 27 2009 vuntz@novell.com
- Update to version 0.7.31:
  + Enhancements:
  - Added TP_ERROR_STR_* constants corresponding to the members
    of the TpError enum, and tp_error_get_dbus_name() mapping the
    latter to the former
  - Updated to telepathy-spec 0.17.25, adding ConnectionRefused,
    ConnectionFailed and ConnectionLost errors, and the new-style
    StreamTube and DBusTube channel types
  - Made tp_g_key_file_get_int64 and _uint64 into public API for
    Mission Control's benefit
  + Fixes:
  - Changed the dbus_daemon member of TpProxy to be removed in
    dispose, rather than just after the invalidated signal
  - Fixed a null pointer dereference if a TpConnectionManager is
    resurrected during dispose
  - Fixed a use-after-free when the user-supplied object in
    tp_connection_manager_call_when_ready is destroyed after the
    CM becomes ready
  - Fixed tp_dbus_daemon_request_name,
    tp_dbus_daemon_release_name and
    _tp_dbus_daemon_get_name_owner to fail gracefully if the
    TpDBusDaemon has been invalidated
* Tue May 19 2009 vuntz@novell.com
- Update to version 0.7.30:
  + API changes:
  - tp_proxy_add_interface_by_id() may not be called on an
    invalidated proxy. (It never made sense to do this, but now
    telepathy-glib will complain if you do.)
  + Enhancements:
  - Added tp_dbus_daemon_request_name() and
    tp_dbus_daemon_release_name(). (Fixes fdo#21771.)
  - Update to telepathy-spec 0.17.23, adding the Terminated
    error.
  - Added optional support for Shave, to give kernel-style pretty
    make output. (This is disabled by default; to enable it, pass
  - -enable-shave to configure.)
  - Channel introspection will now fail more quickly when the
    channel is invalidated.
  + Fixes:
  - Generated GInterfaces now install type information sooner,
    fixing a bug where object construction could make dbus-glib
    assert.
  + fdo#21792:
    tp_presence_mixin_simple_presence_fill_contact_attributes
    asserts if get_contact_statuses returns NULL.
* Sun Apr  5 2009 vuntz@novell.com
- Update to version 0.7.29:
  + Enhancements:
  - TpBaseConnectionManager, tp_cm_param_setter_offset: support
    parameters of various extra types - object path, double,
    64-bit signed and unsigned integer, array of strings, array
    of bytes - and add regression tests
  - TpContact: enhance documentation to spell out that change
    notification is via GObject::notify::alias etc.
  - tp_asv_new(), a shorthand for creating hash tables from
    strings to slice-allocated GValues, along with tp_asv_set_*
    and tp_asv_take_* helpers to add entries to such hash tables.
    (Fixes fdo#20942)
* Wed Mar 25 2009 vuntz@novell.com
- Update to version 0.7.28:
  + API changes:
  - Use the prefix for D-Bus errors specified by telepathy-spec,
    not something telepathy-glib made up (changing .Errors to the
    correct .Error). This was a regression in telepathy-glib 0.7.1.
  + Enhancements:
  - Update to telepathy-spec 0.17.22, adding
    TP_ARRAY_TYPE_SOCKET_ADDRESS_IP_LIST,
    TP_ARRAY_TYPE_STRING_STRING_MAP_LIST,
    TP_STRUCT_TYPE_SOCKET_ADDRESS_IP
  - Extend the 'callable' example connection manager to support
    simulated incoming calls, support simulated contacts who
    never answer, are busy or terminate the call, and comply with
    telepathy-spec 0.17.22
  + Fixes:
  - fdo#20729: csh (chatroom) example connection manager: comply
    with telepathy-spec 0.17.21 by always allowing the user to
    leave the Group
  - Cancel GetParameters call if the CM crashes, fixing an
    assertion failure in
    tp_connection_manager_continue_introspection
* Wed Mar 18 2009 vuntz@novell.com
- Update to version 0.7.27:
  + Enhancements:
  - fdo#18220: make it much less verbose to construct
    string/variant maps (a{sv}) by adding functions like
    tp_g_value_slice_new_uint().
  - Make example connection managers installable (with
  - -enable-installed-examples)
  - Add an example connection manager that has dummy
    StreamedMedia channels
  - Add an example connection manager that has dummy ContactList
    channels vaguely resembling the XMPP roster
  - Update to telepathy-spec 0.17.21 (adding
    TP_CHANNEL_GROUP_FLAG_MESSAGE_DEPART and
    TP_CHANNEL_MEDIA_CAPABILITY_NAT_TRAVERSAL_ICE_UDP)
  + Fixes:
  - fdo#20646: in TpChannel, when adding contacts to one of the
    Group sets, remove them from both of the others
  - Use AM_PATH_PYTHON to detect the Python version
  - In TpGroupMixin, let implementations allow the self-handle to
    be removed regardless of whether the CAN_REMOVE flag is set.
  - fdo#20165: fix a use-after-free in
    tp_base_connection_register() that causes connection managers
    to assert if they have not already called
    tp_dbus_daemon_dup() or tp_run_connection_manager()
  - Fix some memory leaks when making TpContact objects, when
    holding handles in TpContactsMixin, when filling contact
    attributes in TpPresenceMixin, when setting simple presence,
    and in the regression tests
  - Update the valgrind suppressions file to cope with new
    telepathy-glib code, GTest, and glibc 2.9
  - Fix compilation with gtkdoc 1.11, which is stricter about the
    contents of Since: annotations, and parses more comments
* Tue Feb 17 2009 vuntz@novell.com
- Update to version 0.7.26:
  + Enhancements:
  - Add tp_connection_manager_call_when_ready()
  - When constructing TpConnectionManager, if the .manager file
    is missing or can't be read, always try to activate the
    connection manager (in practice, this is what's wanted)
  - fdo#18291: when listing connection managers, wait for them to
    all be ready
  - fdo#18056: add method-based accessors for TpConnectionManager
    members
  - fdo#17519: track the Connection's SelfHandle property in
    TpConnection
  - Add tp_dbus_daemon_dup(), convenient API to share a
    starter-bus connection
  - Generate GTypes for arrays of mappings, and improve use of
    the type-generation functions
  - Add tp_intset_new_containing(), a convenient factory for sets
    with exactly one member
  + Deprecations:
  - Deprecate tp_get_bus_proxy()
  + Fixes:
  - Reduce our reliance on making a DBusGProxy for the
    dbus-daemon (working towards avoiding overly-broad
    NameOwnerChanged matches)
  - fdo#18832 (partially addressed): document that tp_get_bus()
    can call exit() and why, and discourage it in processes that
    aren't totally reliant on D-Bus
  - fdo#18207: reliably emit TpConnectionManager::got-info signal
    (although tp_connection_manager_call_when_ready() should be
    used instead)
  - Fix some assertion failures in TpConnectionManager when
    .manager files contain surprising types
  - Parse all currently supported types in .manager files
  + Miscellaneous:
  - Add regression test coverage for TpConnectionManager
- Remove .la file.
* Sun Feb  1 2009 mboman@suse.de
- Update to version 0.7.25:
  + fdo#17588: don't break ABI if errors are re-ordered in a future spec
    version
  + fdo#19688: don't assert when getting contacts by ID if none of the
    identifiers supplied are valid
  + TpPresenceMixin: don't allow setting statuses that are flagged as not
    settable on the user themselves
  + TpPresenceMixin: never allow statuses of type OFFLINE, UNKNOWN or ERROR
    to be set on the user themselves, and warn if the connection manager
    got this wrong
  + Fix a memory leak in tp_presence_mixin_get_statuses()
* Thu Jan 29 2009 hfiguiere@suse.de
- Update to version 0.7.24
  + Update to telepathy-spec 0.17.19: better error handling
  + Different error when a TpConnection is invalidated
  + Add a client binding for the extensible error reporting
  + Add File Transfer to the documentation
* Wed Jan 28 2009 hfiguiere@suse.de
- Update to version 0.7.23
  + Updated to spec version 0.17.18: file transfer, better error
    handling (fdo#19609), etc
  + Exported ABI symbols cleanup
  + Documentation fixes
  + Annotation fixes.
* Tue Jan 13 2009 hfiguiere@suse.de
- Update to version 0.7.22
  + Accept message=NULL in tp_group_mixin_change_members, as documented and true
    in the past, rather than crashing.
* Mon Jan 12 2009 hfiguiere@suse.de
- Update to version 0.7.21
  + Updated to spec version 0.17.17
  + (Finally) merged TpMessageMixin, which can be used in place of TpTextMixin to
    implement the Messages interface on Text channels.
  + The examples have been made more exemplary.
  + Added a TP_COMPILER_WARNINGS macro to simplify choosing compiler warnings in
    configure.ac
  + Added support to TpGroupMixin for emitting the MembersChangedDetailed signal
    (fdo#19050 and fdo#19052), and to TpChannel for listening to it when possible
    (fdo#19051).
  + Added tp_channel_get_identifier
  + Added support for parsing the dbus-property CM parameter flag (introduced in
    spec 0.17.16) from .manager files (fdo#19053).
  + fdo#19101: tp_connection_get_contacts_by_id() crashes
* Thu Jan  1 2009 mboman@suse.de
- Update to version 0.7.20:
  + Too many fixes/changes to list. Please see NEWS for full details.
* Wed Oct 22 2008 maw@suse.de
- Make debug packages require a specific %%{version}-%%{release}.
* Sun Oct 19 2008 mboman@suse.de
- Update to version 0.7.17:
  + Updated to spec 0.17.13, which adds Requested, InitiatorHandle and
    InitiatorID properties to Channel
  + Updated two example CMs (echo and channelspecific) to spec 0.17.13 too
  + Added handle reference-counting helpers, which should be used instead
    of using the HoldHandles, RequestHandles and ReleaseHandles D-Bus API
    directly
  + Added C accessors for TpProxy's read-only properties, and for
    TpConnection's connection-ready property
  + Added some infrastructure for test coverage analysis using lcov
  + Moved some of the release/checking machinery to tools/telepathy.am
    for easy pasting into other Telepathy projects
  + The first time TP_ERRORS is used, the error domain is now automatically
    registered with dbus-glib
  + Added sanity checks (g_return_if_fail/g_critical) to TpConnection,
    TpProxy, TpDBusDaemon and tp_dbus_check_* public API
  + tp_handle_is_valid and tp_handles_are_valid raise InvalidHandle on
    failure, not InvalidArgument (numerous methods in telepathy-spec require
    InvalidHandle to be raised, so this should make most CMs more
    spec-compliant)
  + The test and example CMs raise NotAvailable on syntactically incorrect
    strings, rather than InvalidArgument (which is not spec-compliant)
  + The example valgrind suppressions file now works if libdbus was not
    installed in /usr, or if glibc is version 2.7
  + fdo#17502: fixed documentation of the #include for TpDBusPropertiesMixin
  + Fixed a memory leak in TpContactsMixin
* Mon Oct 13 2008 sbrabec@suse.cz
- Signed-off.
* Thu Oct  2 2008 dominique-opensuse@leuenberger.net
- Update to version 0.7.16:
  * We now support EnsureChannel on the Requests interface - to implement this,
  put a suitable function pointer in TpChannelManagerIface::ensure_channel
  * Channel factories' RequestChannel implementations no longer need to
  validate handles - TpBaseConnection now does this automatically
  * Added a function to compare presence types in order of "availability"
  Fixes:
  * The gtkdoc now documents GInterfaces' signals and properties (fd.o #16995,
  fd.o #17308)
  * TpBaseConnection::self_handle is unreffed and cleared slightly later,
  for the benefit of channel managers that want to use it in their
  status-changed(Disconnected) callback
  * Fixed a compiler warning on platforms with daemon(3) in their libc
  * TpChannelManager can no longer be crashed by asking for unsupported
  handle types
* Tue Aug 19 2008 hfiguiere@suse.de
- Upgrade to 0.7.14
  * Updated to specification 0.17.9
  * Added TpContactsMixin, a generic implementation of the Contacts interface
  * Added tp_connection_get_status() convenience accessor for status and
    status-reason properties
  * Altered tp_debug_divert_messages() to support a "+" prefix to filenames,
    which changes the mode from truncate to append: you can now set something
    like GABBLE_LOGFILE="+gabble.log" to append to an existing log
* Tue Aug 19 2008 hfiguiere@suse.de
- Keep the *.la files as they are needed for telepathy-mission-control
* Fri Aug  8 2008 hfiguiere@suse.de
- Update to 0.7.13
  * couple of minor API added
  * fdo#14828, fod#14829: TpChannel and TpConnection can be subclassed
  * TpChannel tracks the Group interface automatically (fd.o #14180)
  * TpConnectionManager no longer causes a crash if destroyed before it has
  read the .manager file (fd.o #16774)
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Thu Jul 17 2008 hfiguiere@suse.de
- Update to 0.7.11
  * lot of bugfixes.
* Wed Mar 12 2008 hfiguiere@suse.de
- Update to 0.7.5.
  + Updated to specification 0.17
  + Improved support for connection managers whose parameters aren't known
    at compile time
  + Build system refactoring
  + Large improvements in GType based code.
- remove .la files (bnc#357465)
* Thu Feb  7 2008 mauro@suse.de
- Fixed bnc #359715 - libtelepathy-glib0 and its -devel now have
  proper Requires.
* Thu Jan 31 2008 sbrabec@suse.cz
- Devhelp documentation moved to the separate package (bnc#248813).
* Sat Dec  1 2007 jpr@suse.de
- Initial checkin
